@@ -4,7 +4,7 @@ methods that act upon a transfer function to gain functions such as the
 mass function.
 '''
 
-version = '1.0.6'
+version = '1.0.7'
 
 ###############################################################################
 # Some Imports
@@ -660,7 +660,7 @@ class Perturbations(object):
                 M_new, dlnM = np.linspace(np.log10(m), max_M, 4097, retstep=True)
                 mf_new = mf(M_new)
                 integ = 10 ** (M_new + mf_new)
-                mgtm[i] = np.log10(intg.romb(integ, dx=dlnM) / np.log(10))
+                mgtm[i] = intg.romb(integ, dx=dlnM) / np.log(10)
 
         return mgtm
 
@@ -696,7 +696,7 @@ class Perturbations(object):
                 M_new, dlnM = np.linspace(min_M, np.log10(m), 4097, retstep=True)
                 mf_new = mf(M_new)
                 integ = 10 ** (mf_new)
-                nltm[i] = np.log10(intg.romb(integ, dx=dlnM) / np.log(10))
+                nltm[i] = intg.romb(integ, dx=dlnM) / np.log(10)
 
         return nltm
 
@@ -733,7 +733,7 @@ class Perturbations(object):
                 M_new, dlnM = np.linspace(min_M, np.log10(m), 4097, retstep=True)
                 mf_new = mf(M_new)
                 integ = 10 ** (M_new + mf_new)
-                mltm[i] = np.log10(intg.romb(integ, dx=dlnM) / np.log(10))
+                mltm[i] = intg.romb(integ, dx=dlnM) / np.log(10)
 
         return mltm
 
